@@ -3,3 +3,7 @@
 #' @importFrom R6 R6Class
 #' @useDynLib vdiffr
 NULL
+
+old_freetype <- function() {
+  gdtools::version_freetype() < "2.6.0"
+}
